<template>
  <PageLayoutWithBg class="index-page-wrapper" :title="''" :need-auth="false">
    <template #left>
      <div class="menu-btn-wrapper menu-logo">
        <img :src="IconLogo" class="logo" />
      </div>
    </template>
    <div class="home-header">
      <div class="home-searchbar-wrapper">
        <div class="searchbar-container">
          <BlSearchbar v-model.trim="searchValue" placeholder="搜索任务"></BlSearchbar>
        </div>
        <div class="city-btn" @click="goCitySelect">
          <Location2 :size="16" />
          <div class="city-btn-text">{{ locationCity }}</div>
        </div>
      </div>
      <div class="home-banner-wrapper">
        <nut-swiper :auto-play="3000">
          <nut-swiper-item v-for="(item, index) in list" :key="index">
            <img :src="item" class="banner-img" draggable="false" />
          </nut-swiper-item>
        </nut-swiper>
      </div>
    </div>
    <ProTabs
      v-model="queryState.orderType"
      name="home-tab"
      :showPaneContent="false"
      class="home-tabs"
      isTransparent
      title-gutter="12"
      title-scroll
    >
      <ProTabPane :title="`推荐`" :pane-key="HomeOrderType.Recommend"></ProTabPane>
      <ProTabPane :title="`最新`" :pane-key="HomeOrderType.LastShelfTime"></ProTabPane>
      <template #right>
        <Menu>
          <MenuItem
            v-model="queryState.orderByProperty"
            title="筛选"
            ref="selectItem"
            :options="[
              { text: '排序', value: 'userId' },
              { text: '按关注时间', value: 'creationTime' },
            ]"
          />
        </Menu>
      </template>
    </ProTabs>
    <InfiniteLoading
      scrollViewClassName="common-infinite-scroll-list home-list"
      v-bind="infiniteLoadingProps"
      :key="queryState.orderType"
    >
      <template #renderItem="{ item }">
        <TaskCard />
      </template>
    </InfiniteLoading>
  </PageLayoutWithBg>
</template>

<script setup lang="ts">
import { useUser } from '@/hooks';
import { useUserStore } from '@/stores/modules/user';
import { RectDown, Location2 } from '@nutui/icons-vue-taro';
import Taro from '@tarojs/taro';
import { LocationUtils, trim } from '@12333/utils';
import _ from 'lodash';
import IconLogo from '@/assets/home/icon-logo.png';
import { useInfiniteLoading } from '@12333/hooks';
import { OrderInputType } from '@12333/constants';
import * as orderServices from '@12333/services/api/Order';
import { TaskCard, ProTabs, ProTabPane } from '@12333/components';
import { HomeOrderType } from './constants';

const { locationCity } = useUser();

Taro.usePageScroll(() => {
  console.log('11', 11);
});

const searchValue = ref('');

const queryState = reactive({
  searchValueTrim: '',
  orderType: HomeOrderType.Recommend,
  orderByProperty: 'userId',
});

const handleSearch = _.debounce(function () {
  queryState.searchValueTrim = trim(searchValue.value);
}, 300);

const userStore = useUserStore();

function goCitySelect() {
  Taro.navigateTo({
    url: RouterPath.citySelect,
  });
}

const list = ref([
  'https://storage.360buyimg.com/jdc-article/NutUItaro34.jpg',
  'https://storage.360buyimg.com/jdc-article/NutUItaro2.jpg',
  'https://storage.360buyimg.com/jdc-article/welcomenutui.jpg',
  'https://storage.360buyimg.com/jdc-article/fristfabu.jpg',
]);

const { infiniteLoadingProps } = useInfiniteLoading(
  ({ pageParam }) => {
    let params: API.FrontOrderListInput = {
      pageModel: {
        rows: 20,
        page: pageParam,
        orderInput: [
          queryState.orderType === HomeOrderType.Recommend
            ? { property: 'isRecommend', order: OrderInputType.Desc }
            : { property: 'lastShelfTime', order: OrderInputType.Desc },
        ],
      },
    };

    return orderServices.getFrontOrderList(params, {
      showLoading: false,
    });
  },
  {
    queryKey: ['orderServices/getFrontOrderList', queryState],
  }
);
</script>

<style lang="scss">
@import '@/styles/common.scss';

.index-page-wrapper {
  .menu-logo {
    padding: 0;

    .logo {
      width: 96px;
      height: 64px;
    }
  }

  .home-searchbar-wrapper {
    padding: 32px 0;
    display: flex;

    .searchbar-container {
      flex: 1;
      min-width: 0;
    }

    .city-btn {
      display: flex;
      align-items: center;
      padding-left: 36px;
      color: boleGetCssVar('text-color', 'primary');

      .city-btn-text {
        max-width: 200px;
        @include ellipsis;
        margin-left: 12px;
        font-size: 30px;
      }
    }
  }

  .home-banner-wrapper {
    .banner-img {
      width: 100%;
      height: 260px;
      object-fit: cover;
    }
  }

  .home-header {
    padding: 0 boleGetCssVar('size', 'body-padding-h');
  }
}

.home-list {
  @include infiniteLoadingInTabBarPage;
}
</style>
